==> sal-distributed-datastore-1.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/config/distributed/datastore/provider/rev140612/HeartbeatIntervalType.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.config.distributed.datastore.provider.rev140612;
import java.io.Serializable;
import java.beans.ConstructorProperties;
import java.util.Objects;

public class HeartbeatIntervalType
 implements Serializable {
    private static final long serialVersionUID = 6964103311731561611L;
    private final java.lang.Integer _value;

    private static void check_valueRange(final int value) {
        if (value >= 100 && value <= 65535) {
            return;
        }
        throw new IllegalArgumentException(String.format("Invalid range: %s, expected: [[100..65535]].", value));
    }

    @ConstructorProperties("value")
    public HeartbeatIntervalType(java.lang.Integer _value) {
        if (_value != null) {
            check_valueRange(_value);
        }
    
    
        Objects.requireNonNull(_value, "Supplied value may not be null");
    
        this._value = _value;
    }
    
    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public HeartbeatIntervalType(HeartbeatIntervalType source) {
        this._value = source._value;
    }

    public static HeartbeatIntervalType getDefaultInstance(String defaultValue) {
        return new HeartbeatIntervalType(java.lang.Integer.valueOf(defaultValue));
    }

    public java.lang.Integer getValue() {
        return _value;
    }


    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + Objects.hashCode(_value);
        return result;
    }

    @Override
    public boolean equals(java.lang.Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        HeartbeatIntervalType other = (HeartbeatIntervalType) obj;
        if (!Objects.equals(_value, other._value)) {
            return false;
        }
        return true;
    }

    @Override
    public java.lang.String toString() {
        java.lang.StringBuilder builder = new java.lang.StringBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.config.distributed.datastore.provider.rev140612.HeartbeatIntervalType.class.getSimpleName()).append(" [");
        boolean first = true;
    
        if (_value != null) {
            if (first) {
                first = false;
            } else {
                builder.append(", ");
            }
            builder.append("_value=");
            builder.append(_value);
        }
        return builder.append(']').toString();
    }
}

==> sal-distributed-datastore-1.9.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/config/distributed/datastore/provider/rev140612/HeartbeatIntervalType.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.config.distributed.datastore.provider.rev140612;
import com.google.common.base.MoreObjects;
import java.beans.ConstructorProperties;
import java.io.Serializable;
import java.lang.Integer;
import java.lang.Override;
import java.lang.String;
import java.util.Objects;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.TypeObject;

public class HeartbeatIntervalType
 implements TypeObject, Serializable {
    private static final long serialVersionUID = 6964103311731561611L;
    private final Integer _value;

    private static void check_valueRange(final int value) {
        if (value >= 100 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[100..65535]]", value);
    }

    @ConstructorProperties("value")
    public HeartbeatIntervalType(Integer _value) {
        if (_value != null) {
            check_valueRange(_value);
        }
    
        Objects.requireNonNull(_value, "Supplied value may not be null");
    
        this._value = _value;
    }
    
    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public HeartbeatIntervalType(HeartbeatIntervalType source) {
        this._value = source._value;
    }

    public static HeartbeatIntervalType getDefaultInstance(String defaultValue) {
        return new HeartbeatIntervalType(Integer.valueOf(defaultValue));
    }

    public Integer getValue() {
        return _value;
    }


    @Override
    public int hashCode() {
        return CodeHelpers.wrapperHashCode(_value);
    }

    @Override
    public boolean equals(java.lang.Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        HeartbeatIntervalType other = (HeartbeatIntervalType) obj;
        if (!Objects.equals(_value, other._value)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper(HeartbeatIntervalType.class);
        CodeHelpers.appendValue(helper, "_value", _value);
        return helper.toString();
    }
}
